@@ -52,7 +52,7 @@ create_window (void)
 
 	sw = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 100, 10, 100, 100)),
 				      GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 100, 10, 100, 100)));
-	
+
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_container_add (GTK_CONTAINER (sw), canvas);
 
@@ -71,11 +71,13 @@ create_window (void)
 int
 main (int argc, char *argv[])
 {
+	GnomeProgram *ccprogram;
+
         bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
         textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("gnome-control-center",
+	ccprogram = gnome_program_init ("gnome-control-center",
 			    VERSION, LIBGNOMEUI_MODULE,
 			    argc, argv,
 			    GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
