@@ -158,9 +158,9 @@ set_ctrl_from_gconf (XkbDescRec *desc, GConfClient *client,
 static void
 set_server_from_gconf (GConfEntry *ignored)
 {
-	GConfClient	*client = gconf_client_get_default ();
 	XkbDescRec	*desc;
 	gboolean	 enable_accessX;
+	GConfClient     *client = gnome_settings_daemon_get_conf_client ();
 
 	desc = get_xkb_desc_rec ();
 	if (!desc) {
@@ -283,8 +283,6 @@ set_server_from_gconf (GConfEntry *ignored)
 
 	XSync (GDK_DISPLAY (), FALSE);
 	gdk_error_trap_pop ();
-
-	g_object_unref (client);
 }
 
 static gboolean
@@ -299,7 +297,7 @@ ax_response_callback (gint response_id, guint revert_controls_mask, gboolean ena
 	    case GTK_RESPONSE_REJECT:
 	    case GTK_RESPONSE_CANCEL:
 		{
-		    GConfClient *client = gconf_client_get_default ();
+		    GConfClient *client = gnome_settings_daemon_get_conf_client ();
 
 		    /* we're reverting, so we invert sense of 'enabled' flag */
 		    d ("cancelling AccessX request");
@@ -377,6 +375,7 @@ warning_dialog_post (GCallback response, gboolean *enabled,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), user_action_string);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "gnome-dev-keyboard");
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
@@ -419,7 +418,7 @@ static void
 set_gconf_from_server (GConfEntry *ignored)
 {
 	gboolean	in_gconf;
-	GConfClient	*client = gconf_client_get_default ();
+	GConfClient	*client = gnome_settings_daemon_get_conf_client ();
 	GConfChangeSet *cs = gconf_change_set_new ();
 	XkbDescRec	*desc = get_xkb_desc_rec ();
 	gboolean changed = FALSE, slowkeys_changed, stickykeys_changed;
@@ -519,7 +518,6 @@ set_gconf_from_server (GConfEntry *ignored)
 		gconf_client_suggest_sync (client, NULL);
 	}
 	gconf_change_set_unref (cs);
-	g_object_unref (client);
 }
 
 static GdkFilterReturn 
